=======
History
=======

0.2.5 (2021-12-03)
    - Manage trained models by Git LFS

------------------

0.2.4 (2021-11-30)
    - Added pip optional dependencies install support.
    - pip install cosmic-conn # basic install for CR detection
    - pip install cosmic-conn[webapp] # include Flask for the web app 
    - pip install cosmic-conn[develop] # all dependencies for development

------------------

0.2.3 (2021-07-19)
    - fixed the disappeared scroll bar in Mac's Chrome

------------------

0.2.0 (2021-06-27)
    - Initial release verison

------------------

0.1.9 (2021-05-11)
    - Web app fully functional

------------------

0.1.0 (2021-04-19)
    - Test release on PyPI.